@@ -10,32 +10,32 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.12';
-$DATE = '2003/07/27';
+$VERSION = '0.13';
+$DATE = '2003/07/31';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.12 2003/07/27), 'revised 0.11'],
-    'MANIFEST' => [qw(0.12 2003/07/27), 'generated, replaces 0.11'],
-    'Makefile.PL' => [qw(0.12 2003/07/27), 'generated, replaces 0.11'],
-    'README' => [qw(0.12 2003/07/27), 'generated, replaces 0.11'],
-    'lib/Test/Tech.pm' => [qw(1.11 2003/07/27), 'revised 1.1'],
-    't/Test/Tech/Tech.t' => [qw(0.11 2003/07/27), 'revised 0.1'],
-    't/Test/Tech/techA0.t' => [qw(0.07 2003/07/27), 'revised 0.06'],
-    't/Test/Tech/techA2.txt' => [qw(0.05 2003/06/19), 'unchanged'],
-    't/Test/Tech/techB0.t' => [qw(0.04 2003/07/27), 'revised 0.03'],
-    't/Test/Tech/techC0.t' => [qw(0.07 2003/07/27), 'revised 0.06'],
+    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.13 2003/07/31), 'revised 0.12'],
+    'MANIFEST' => [qw(0.13 2003/07/31), 'generated, replaces 0.12'],
+    'Makefile.PL' => [qw(0.13 2003/07/31), 'generated, replaces 0.12'],
+    'README' => [qw(0.13 2003/07/31), 'generated, replaces 0.12'],
+    'lib/Test/Tech.pm' => [qw(1.12 2003/07/31), 'revised 1.11'],
+    't/Test/Tech/Tech.t' => [qw(0.11 2003/07/27), 'unchanged'],
+    't/Test/Tech/techA0.t' => [qw(0.07 2003/07/27), 'unchanged'],
+    't/Test/Tech/techA2.txt' => [qw(0.06 2003/07/31), 'revised 0.05'],
+    't/Test/Tech/techB0.t' => [qw(0.04 2003/07/27), 'unchanged'],
+    't/Test/Tech/techC0.t' => [qw(0.07 2003/07/27), 'unchanged'],
     't/Test/Tech/techC2.txt' => [qw(0.06 2003/06/21), 'unchanged'],
-    't/Test/Tech/techC3.txt' => [qw(0.06 2003/06/21), 'unchanged'],
-    't/Test/Tech/techD0.d' => [qw(0.03 2003/07/27), 'revised 0.02'],
+    't/Test/Tech/techC3.txt' => [qw(0.07 2003/07/31), 'revised 0.06'],
+    't/Test/Tech/techD0.d' => [qw(0.03 2003/07/27), 'unchanged'],
     't/Test/Tech/techD2.txt' => [qw(0.06 2003/06/21), 'unchanged'],
     't/Test/Tech/techD3.txt' => [qw(0.06 2003/06/21), 'unchanged'],
     't/Test/Tech/V001024/Test.pm' => [qw(1.24 2003/06/19), 'unchanged'],
     't/Test/Tech/V001015/Test.pm' => [qw(1.15 2003/06/19), 'unchanged'],
-    'tlib/File/Package.pm' => [qw(1.11 2003/07/27), 'new'],
-    'tlib/File/SmartNL.pm' => [qw(1.1 2003/07/27), 'new'],
-    'tlib/Text/Scrub.pm' => [qw(1.09 2003/07/27), 'new'],
+    'tlib/File/Package.pm' => [qw(1.11 2003/07/31), 'unchanged'],
+    'tlib/File/SmartNL.pm' => [qw(1.11 2003/07/31), 'unchanged'],
+    'tlib/Text/Scrub.pm' => [qw(1.09 2003/07/31), 'unchanged'],
 
 );
 
@@ -62,11 +62,11 @@ use vars qw(%INVENTORY);
 
  Test::Tech - Extends the Test program module
 
- Revision: J
+ Revision: K
 
- Version: 0.12
+ Version: 0.13
 
- Date: 2003/07/27
+ Date: 2003/07/31
 
  Prepared for: General Public 
 
@@ -133,7 +133,7 @@ session using the methods under test
 
 =head2 1.3 Document overview.
 
-This document releases Test::Tech version 0.12
+This document releases Test::Tech version 0.13
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -149,8 +149,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/Test-Tech-0.12
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.12
+   http://www.softwarediamonds/packages/Test-Tech-0.13
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.13
 
 
 Restrictions regarding duplication and license provisions
@@ -218,26 +218,26 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_Tech.pm                               0.12    2003/07/27 revised 0.11
- MANIFEST                                                     0.12    2003/07/27 generated, replaces 0.11
- Makefile.PL                                                  0.12    2003/07/27 generated, replaces 0.11
- README                                                       0.12    2003/07/27 generated, replaces 0.11
- lib/Test/Tech.pm                                             1.11    2003/07/27 revised 1.1
- t/Test/Tech/Tech.t                                           0.11    2003/07/27 revised 0.1
- t/Test/Tech/techA0.t                                         0.07    2003/07/27 revised 0.06
- t/Test/Tech/techA2.txt                                       0.05    2003/06/19 unchanged
- t/Test/Tech/techB0.t                                         0.04    2003/07/27 revised 0.03
- t/Test/Tech/techC0.t                                         0.07    2003/07/27 revised 0.06
+ lib/Docs/Site_SVD/Test_Tech.pm                               0.13    2003/07/31 revised 0.12
+ MANIFEST                                                     0.13    2003/07/31 generated, replaces 0.12
+ Makefile.PL                                                  0.13    2003/07/31 generated, replaces 0.12
+ README                                                       0.13    2003/07/31 generated, replaces 0.12
+ lib/Test/Tech.pm                                             1.12    2003/07/31 revised 1.11
+ t/Test/Tech/Tech.t                                           0.11    2003/07/27 unchanged
+ t/Test/Tech/techA0.t                                         0.07    2003/07/27 unchanged
+ t/Test/Tech/techA2.txt                                       0.06    2003/07/31 revised 0.05
+ t/Test/Tech/techB0.t                                         0.04    2003/07/27 unchanged
+ t/Test/Tech/techC0.t                                         0.07    2003/07/27 unchanged
  t/Test/Tech/techC2.txt                                       0.06    2003/06/21 unchanged
- t/Test/Tech/techC3.txt                                       0.06    2003/06/21 unchanged
- t/Test/Tech/techD0.d                                         0.03    2003/07/27 revised 0.02
+ t/Test/Tech/techC3.txt                                       0.07    2003/07/31 revised 0.06
+ t/Test/Tech/techD0.d                                         0.03    2003/07/27 unchanged
  t/Test/Tech/techD2.txt                                       0.06    2003/06/21 unchanged
  t/Test/Tech/techD3.txt                                       0.06    2003/06/21 unchanged
  t/Test/Tech/V001024/Test.pm                                  1.24    2003/06/19 unchanged
  t/Test/Tech/V001015/Test.pm                                  1.15    2003/06/19 unchanged
- tlib/File/Package.pm                                         1.11    2003/07/27 new
- tlib/File/SmartNL.pm                                         1.1     2003/07/27 new
- tlib/Text/Scrub.pm                                           1.09    2003/07/27 new
+ tlib/File/Package.pm                                         1.11    2003/07/31 unchanged
+ tlib/File/SmartNL.pm                                         1.11    2003/07/31 unchanged
+ tlib/Text/Scrub.pm                                           1.09    2003/07/31 unchanged
 
 
 =head2 3.3 Changes
@@ -411,6 +411,13 @@ The test of this module will precede immediately.
 The test support files in the tlib directory will vanish after
 the installtion.
 
+=item Test-Tech-0.13
+
+If there is no diagianotic message and there is a test name, 
+then use the test name also for the diagnostic message.
+Diagnostic message appears in brackets after the expected
+value.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -444,8 +451,8 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/Test-Tech-0.12
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.12
+   http://www.softwarediamonds/packages/Test-Tech-0.13
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.13
 
 
 =item Prerequistes.
@@ -568,11 +575,11 @@ __DATA__
 DISTNAME: Test-Tech^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.12^
+VERSION : 0.13^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.11^
-REVISION: J^
+PREVIOUS_RELEASE: 0.12^
+REVISION: K^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: 
@@ -786,6 +793,13 @@ The test of this module will precede immediately.
 The test support files in the tlib directory will vanish after
 the installtion.
 
+\=item Test-Tech-0.13
+
+If there is no diagianotic message and there is a test name, 
+then use the test name also for the diagnostic message.
+Diagnostic message appears in brackets after the expected
+value.
+
 \=back
 
 ^
